import 'dart:convert';
import 'dart:io';

import 'package:meta/meta.dart';
import 'package:http/http.dart' as http;

import 'record.dart';

Future<List<Record>> getAllTranslation(
    {@required String tableKey, @required String apiKey}) async {
  List records = [];
  final uri = Uri.encodeFull(
      'https://api.airtable.com/v0/$tableKey?sort[0][field]=key');
  var data = {};

  do {
    String url = data['offset'] != null ? '$uri&offset=${data['offset']}' : uri;
    http.Response response = await http
        .get(url, headers: {HttpHeaders.authorizationHeader: 'Bearer $apiKey'});
    if (response.statusCode > 400) {
      exitCode = 2;
      throw HttpException(
          'Error getting uri: ${response.statusCode}: ${response.reasonPhrase}');
    }
    data = json.decode(response.body);
    records.addAll(data['records']);
  } while (data['offset'] != null);

  return records.map((record) => Record.fromJson(record)).toList();
}

Future writeTranslationsFile(
    {@required List<Record> records, @required String path}) async {
  Map<String, Map<String, String>> filesToWrite = {};
  for (Record record in records) {
    for (String key in record.fields.keys) {
      if (filesToWrite[key] == null) filesToWrite[key] = {};
      filesToWrite[key][record.key] = record.fields[key];
    }
  }
  Directory langDir = Directory(path);
  if (await langDir.exists() == false) {
    await langDir.create(recursive: true);
  }
  for (String lang in filesToWrite.keys) {
    File langFile = new File('$path/intl_$lang.json');
    await langFile.writeAsString(jsonEncode(filesToWrite[lang]));
  }
}
